@@ -45,7 +45,7 @@ def main(args=None):
     log_pack.scc_logger(logger)
     logger.setLevel('DEBUG')
     start_time = datetime.datetime.now()
-    logger.info("--------------------------------")
+    logger.info("----------------------------------------------------------------")
     logger.info("------ Processing started on %s ------" % start_time)
     
 #Ignores all warnings --> they are not printed in terminal
@@ -72,7 +72,7 @@ def main(args=None):
     try:
         setup_directories(cfg)
     except Exception as e:
-        logger.error("Error while setting up required directories.")
+        logger.error("Error while setting up required directories ")
         sys.exit(3)
     
 # Add filepath configuration for logging purposes
@@ -85,6 +85,7 @@ def main(args=None):
     margin = 0.63
     
 # Get array of input files from an scc database query
+    logger.info("----------------------------------------------------------------")
     logger.info("------ Processing started on %s ------" % start_time)
     logger.info("Quering the measurement paths in the SCC database ")
     try:
@@ -99,7 +100,7 @@ def main(args=None):
 ###############################################################################
 # A.1) Reading lidar profiles
 # Optical Profiles
-    logger.info("------ Section A: Reading the SCC files ")
+    logger.info("Section A: Reading the SCC files ")
     try:
         dt_start_arr, alt_arr, prod_arr, metadata = \
             read_scc_db(files, end_fill = alphas)
@@ -111,13 +112,13 @@ def main(args=None):
 ###############################################################################
 # B) Geometrical retrievals
 ############################################################################### 
-    logger.info("------ Section B: Proceeding to the layering algorithm ")
     list_geom = []
     list_geom_dts = []
     list_dates = []
 
     for i in range(0, len(files)):
-        logger.info(f"       Proccessing file: {os.path.basename(files[i])} ")
+        logger.info(f"****** Proccessing file: {os.path.basename(files[i])} ******")
+        logger.info("Section B: Proceeding to the layering algorithm ")
 
         norm = prod_arr[i]/det_lims[i]
         
@@ -137,7 +138,7 @@ def main(args=None):
         try:
             geom = geom_prop(rl_flag, bases, tops, alt_arr[i], norm, log = logger)
         except Exception as e:
-            logger.error("Error calculating layer properties ")
+            logger.error("Error while calculating layer properties ")
             sys.exit(7)  
         logger.info("       Layer properties succesfully calculated ")
         
@@ -153,8 +154,7 @@ def main(args=None):
 ###############################################################################
 # C) Exporting
 ###############################################################################
-        if i == 0: 
-            logger.info("------ Section C: Exporting layer properties ")
+        logger.info("Section C: Exporting layer properties ")
             
         if len(geom) > 0:
 # C.1) Export to netcdf
@@ -201,7 +201,7 @@ def main(args=None):
     
     logger.info("------ Processing finished on %s ------" % stop_time)
     logger.info("------ Total duration: %s ------" % duration)
-    logger.info("--------------------------------")
+    logger.info("----------------------------------------------------------------")
     logging.shutdown()
     
     sys.exit(0)
\ No newline at end of file
